@@ -113,6 +113,11 @@ VisibilityManager::VisibilityManager(PlasmaQuick::ContainmentView *view)
         connect(this, &VisibilityManager::modeChanged, this, [&]() {
             emit m_latteView->availableScreenRectChangedFrom(m_latteView);
         });
+
+        //! Send frame extents on startup, this is really necessary when recreating a view.
+        //! Such a case is when toggling byPassWM and a view is recreated after disabling editing mode
+        const bool forceUpdate{true};
+        publishFrameExtents(forceUpdate);
     }
 
     m_timerStartUp.setInterval(4000);
@@ -591,6 +596,11 @@ void VisibilityManager::publishFrameExtents(bool forceUpdate)
         m_frameExtentsLocation = m_latteView->location();
         m_frameExtentsHeadThicknessGap = m_latteView->headThicknessGap();
 
+        if (KWindowSystem::isPlatformX11() && m_latteView->devicePixelRatio()!=1.0) {
+            //!Fix for X11 Global Scale
+            m_frameExtentsHeadThicknessGap = qRound(m_frameExtentsHeadThicknessGap * m_latteView->devicePixelRatio());
+        }
+
         QMargins frameExtents(0, 0, 0, 0);
 
         if (m_latteView->location() == Plasma::Types::LeftEdge) {
@@ -603,14 +613,16 @@ void VisibilityManager::publishFrameExtents(bool forceUpdate)
             frameExtents.setTop(m_frameExtentsHeadThicknessGap);
         }
 
-        qDebug() << " -> Frame Extents :: " << m_frameExtentsLocation << " __ " << " extents :: " << frameExtents;
+        bool bypasswm{m_latteView->byPassWM() && KWindowSystem::isPlatformX11()};
 
-        if (!frameExtents.isNull() && !m_latteView->behaveAsPlasmaPanel()) {
+        qDebug() << " -> Frame Extents :: " << m_frameExtentsLocation << " __ " << " extents :: " << frameExtents << " bypasswm :: " << bypasswm;
+
+        if (!frameExtents.isNull() && !m_latteView->behaveAsPlasmaPanel() && !bypasswm) {
             //! When a view returns its frame extents to zero then that triggers a compositor
             //! strange behavior that moves/hides the view totally and freezes entire Latte
             //! this is why we have blocked that setting
             m_wm->setFrameExtents(m_latteView, frameExtents);
-        } else if (m_latteView->behaveAsPlasmaPanel()) {
+        } else if (m_latteView->behaveAsPlasmaPanel() || bypasswm) {
             QMargins panelExtents(0, 0, 0, 0);
             m_wm->setFrameExtents(m_latteView, panelExtents);
             emit frameExtentsCleared();
