@@ -14,8 +14,10 @@
 
 // Qt
 #include <QDebug>
+#include <QtDBus>
 
 // KDE
+#include <KWindowSystem>
 #include <KActivities/Controller>
 
 namespace Latte {
@@ -24,8 +26,12 @@ namespace WindowSystem {
 #define MAXPLASMAPANELTHICKNESS 96
 #define MAXSIDEPANELTHICKNESS 512
 
+#define KWINSERVICE "org.kde.KWin"
+#define KWINVIRTUALDESKTOPMANAGERNAMESPACE "org.kde.KWin.VirtualDesktopManager"
+
 AbstractWindowInterface::AbstractWindowInterface(QObject *parent)
-    : QObject(parent)
+    : QObject(parent),
+      m_kwinServiceWatcher(new QDBusServiceWatcher(this))
 {
     m_activities = new KActivities::Consumer(this);
     m_currentActivity = m_activities->currentActivity();
@@ -56,6 +62,22 @@ AbstractWindowInterface::AbstractWindowInterface(QObject *parent)
         emit currentActivityChanged();
     });
 
+    //! KWin Service tracking
+    m_kwinServiceWatcher->setConnection(QDBusConnection::sessionBus());
+    m_kwinServiceWatcher->setWatchedServices(QStringList({KWINSERVICE}));
+    connect(m_kwinServiceWatcher, &QDBusServiceWatcher::serviceRegistered, this, [this](const QString & serviceName) {
+        if (serviceName == KWINSERVICE && !m_isKWinInterfaceAvailable) {
+            initKWinInterface();
+        }
+    });
+
+    connect(m_kwinServiceWatcher, &QDBusServiceWatcher::serviceUnregistered, this, [this](const QString & serviceName) {
+        if (serviceName == KWINSERVICE && m_isKWinInterfaceAvailable) {
+            m_isKWinInterfaceAvailable = false;
+        }
+    });
+
+    initKWinInterface();
 }
 
 AbstractWindowInterface::~AbstractWindowInterface()
@@ -103,7 +125,19 @@ bool AbstractWindowInterface::isFullScreenWindow(const QRect &wGeometry) const
     }
 
     for (const auto scr : qGuiApp->screens()) {
-        if (wGeometry == scr->geometry()) {
+        auto screenGeometry = scr->geometry();
+
+        if (KWindowSystem::isPlatformX11() && scr->devicePixelRatio() != 1.0) {
+            //!Fix for X11 Global Scale, I dont think this could be pixel perfect accurate
+            auto factor = scr->devicePixelRatio();
+            screenGeometry = QRect(qRound(screenGeometry.x() * factor),
+                                   qRound(screenGeometry.y() * factor),
+                                   qRound(screenGeometry.width() * factor),
+                                   qRound(screenGeometry.height() * factor));
+        }
+
+
+        if (wGeometry == screenGeometry) {
             return true;
         }
     }
@@ -121,12 +155,23 @@ bool AbstractWindowInterface::isPlasmaPanel(const QRect &wGeometry) const
     bool isTouchingVerticalEdge{false};
 
     for (const auto scr : qGuiApp->screens()) {
-        if (scr->geometry().contains(wGeometry.center())) {
-            if (wGeometry.y() == scr->geometry().y() || wGeometry.bottom() == scr->geometry().bottom()) {
+        auto screenGeometry = scr->geometry();
+
+        if (KWindowSystem::isPlatformX11() && scr->devicePixelRatio() != 1.0) {
+            //!Fix for X11 Global Scale, I dont think this could be pixel perfect accurate
+            auto factor = scr->devicePixelRatio();
+            screenGeometry = QRect(qRound(screenGeometry.x() * factor),
+                                   qRound(screenGeometry.y() * factor),
+                                   qRound(screenGeometry.width() * factor),
+                                   qRound(screenGeometry.height() * factor));
+        }
+
+        if (screenGeometry.contains(wGeometry.center())) {
+            if (wGeometry.y() == screenGeometry.y() || wGeometry.bottom() == screenGeometry.bottom()) {
                 isTouchingHorizontalEdge = true;
             }
 
-            if (wGeometry.left() == scr->geometry().left() || wGeometry.right() == scr->geometry().right()) {
+            if (wGeometry.left() == screenGeometry.left() || wGeometry.right() == screenGeometry.right()) {
                 isTouchingVerticalEdge = true;
             }
 
@@ -154,8 +199,19 @@ bool AbstractWindowInterface::isSidepanel(const QRect &wGeometry) const
     QRect screenGeometry;
 
     for (const auto scr : qGuiApp->screens()) {
-        if (scr->geometry().contains(wGeometry.center())) {
-            screenGeometry = scr->geometry();
+        auto curScrGeometry = scr->geometry();
+
+        if (KWindowSystem::isPlatformX11() && scr->devicePixelRatio() != 1.0) {
+            //!Fix for X11 Global Scale, I dont think this could be pixel perfect accurate
+            auto factor = scr->devicePixelRatio();
+            curScrGeometry = QRect(qRound(curScrGeometry.x() * factor),
+                                   qRound(curScrGeometry.y() * factor),
+                                   qRound(curScrGeometry.width() * factor),
+                                   qRound(curScrGeometry.height() * factor));
+        }
+
+        if (curScrGeometry.contains(wGeometry.center())) {
+            screenGeometry = curScrGeometry;
             break;
         }
     }
@@ -187,6 +243,42 @@ bool AbstractWindowInterface::inCurrentDesktopActivity(const WindowInfoWrap &win
     return (winfo.isValid() && winfo.isOnDesktop(currentDesktop()) && winfo.isOnActivity(currentActivity()));
 }
 
+//! KWin Interface
+void AbstractWindowInterface::initKWinInterface()
+{
+    QDBusInterface kwinIface(KWINSERVICE, "/VirtualDesktopManager", KWINVIRTUALDESKTOPMANAGERNAMESPACE, QDBusConnection::sessionBus());
+
+    if (kwinIface.isValid() && !m_isKWinInterfaceAvailable) {
+        m_isKWinInterfaceAvailable = true;
+        qDebug() << " KWIN SERVICE :: is available...";
+
+        QDBusReply<bool> navWrapAround = kwinIface.call("navigationWrappingAround");
+        m_isVirtualDesktopNavigationWrappingAround = navWrapAround.value();
+
+        QDBusConnection bus = QDBusConnection::sessionBus();
+        bool signalconnected = bus.connect(KWINSERVICE,
+                                           "/VirtualDesktopManager",
+                                           KWINVIRTUALDESKTOPMANAGERNAMESPACE,
+                                           "navigationWrappingAroundChanged",
+                                           this,
+                                           SLOT(onVirtualDesktopNavigationWrappingAroundChanged(bool)));
+
+        if (!signalconnected) {
+            qDebug() << " KWIN SERVICE :: Virtual Desktop Manager :: navigationsWrappingSignal is not connected...";
+        }
+    }
+}
+
+bool AbstractWindowInterface::isVirtualDesktopNavigationWrappingAround() const
+{
+    return m_isVirtualDesktopNavigationWrappingAround;
+}
+
+void AbstractWindowInterface::onVirtualDesktopNavigationWrappingAroundChanged(bool navigationWrappingAround)
+{
+    m_isVirtualDesktopNavigationWrappingAround = navigationWrappingAround;
+}
+
 //! Register Latte Ignored Windows in order to NOT be tracked
 void AbstractWindowInterface::registerIgnoredWindow(WindowId wid)
 {
